@@ -21,7 +21,7 @@ import (
 
 	. "github.com/weaveworks/eksctl/integration/runner"
 
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
 	"github.com/weaveworks/eksctl/integration/tests"
