@@ -21,6 +21,9 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/client-go/kubernetes"
 
+	. "github.com/onsi/ginkgo/v2"
+	. "github.com/onsi/gomega"
+
 	. "github.com/weaveworks/eksctl/integration/matchers"
 	. "github.com/weaveworks/eksctl/integration/runner"
 	"github.com/weaveworks/eksctl/integration/tests"
@@ -29,9 +32,6 @@ import (
 	"github.com/weaveworks/eksctl/pkg/cfn/builder"
 	"github.com/weaveworks/eksctl/pkg/eks"
 	"github.com/weaveworks/eksctl/pkg/testutils"
-
-	. "github.com/onsi/ginkgo"
-	. "github.com/onsi/gomega"
 )
 
 var params *tests.Params
@@ -39,79 +39,66 @@ var params *tests.Params
 func init() {
 	// Call testing.Init() prior to tests.NewParams(), as otherwise -test.* will not be recognised. See also: https://golang.org/doc/go1.13#testing
 	testing.Init()
-	params = tests.NewParams("IPv6")
+	params = tests.NewParams("ipv6")
 }
 
 func TestIPv6(t *testing.T) {
 	testutils.RegisterAndRun(t)
 }
 
+var clusterConfig *api.ClusterConfig
+
+var _ = BeforeSuite(func() {
+	f, err := ioutil.TempFile("", "kubeconfig-")
+	Expect(err).NotTo(HaveOccurred())
+	params.KubeconfigPath = f.Name()
+	params.KubeconfigTemp = true
+
+	clusterConfig = api.NewClusterConfig()
+	clusterConfig.Metadata.Name = params.ClusterName
+	clusterConfig.Metadata.Version = api.LatestVersion
+	clusterConfig.Metadata.Region = params.Region
+	clusterConfig.KubernetesNetworkConfig.IPFamily = "iPv6"
+	clusterConfig.VPC.NAT = nil
+	clusterConfig.IAM.WithOIDC = api.Enabled()
+	clusterConfig.Addons = []*api.Addon{
+		{
+			Name: api.VPCCNIAddon,
+		},
+		{
+			Name: api.KubeProxyAddon,
+		},
+		{
+			Name: api.CoreDNSAddon,
+		},
+	}
+	clusterConfig.ManagedNodeGroups = []*api.ManagedNodeGroup{
+		{
+			NodeGroupBase: &api.NodeGroupBase{
+				Name: "mng-1",
+			},
+		},
+	}
+
+	data, err := json.Marshal(clusterConfig)
+	Expect(err).ToNot(HaveOccurred())
+
+	cmd := params.EksctlCreateCmd.
+		WithArgs(
+			"cluster",
+			"--config-file", "-",
+			"--verbose", "4",
+			"--kubeconfig", params.KubeconfigPath,
+		).
+		WithoutArg("--region", params.Region).
+		WithStdin(bytes.NewReader(data))
+	Expect(cmd).To(RunSuccessfully())
+})
+
 var _ = Describe("(Integration) [EKS IPv6 test]", func() {
-	var (
-		clusterConfig *api.ClusterConfig
-	)
 
 	Context("Creating a cluster with IPv6", func() {
-		clusterName := params.NewClusterName("ipv6")
-
-		BeforeSuite(func() {
-			f, err := ioutil.TempFile("", "kubeconfig-")
-			Expect(err).NotTo(HaveOccurred())
-			params.KubeconfigPath = f.Name()
-			params.KubeconfigTemp = true
-
-			clusterConfig = api.NewClusterConfig()
-			clusterConfig.Metadata.Name = clusterName
-			clusterConfig.Metadata.Version = api.LatestVersion
-			clusterConfig.Metadata.Region = params.Region
-			clusterConfig.KubernetesNetworkConfig.IPFamily = "iPv6"
-			clusterConfig.VPC.NAT = nil
-			clusterConfig.IAM.WithOIDC = api.Enabled()
-			clusterConfig.Addons = []*api.Addon{
-				{
-					Name: api.VPCCNIAddon,
-				},
-				{
-					Name: api.KubeProxyAddon,
-				},
-				{
-					Name: api.CoreDNSAddon,
-				},
-			}
-			clusterConfig.ManagedNodeGroups = []*api.ManagedNodeGroup{
-				{
-					NodeGroupBase: &api.NodeGroupBase{
-						Name: "mng-1",
-					},
-				},
-			}
-
-			data, err := json.Marshal(clusterConfig)
-			Expect(err).ToNot(HaveOccurred())
-
-			cmd := params.EksctlCreateCmd.
-				WithArgs(
-					"cluster",
-					"--config-file", "-",
-					"--verbose", "4",
-					"--kubeconfig", params.KubeconfigPath,
-				).
-				WithoutArg("--region", params.Region).
-				WithStdin(bytes.NewReader(data))
-			Expect(cmd).To(RunSuccessfully())
-		})
-
-		AfterSuite(func() {
-			cmd := params.EksctlDeleteCmd.WithArgs(
-				"cluster", clusterName,
-				"--verbose", "2",
-			)
-			Expect(cmd).To(RunSuccessfully())
-
-			if params.KubeconfigTemp {
-				os.Remove(params.KubeconfigPath)
-			}
-		})
+		clusterName := params.ClusterName
 
 		It("should support ipv6", func() {
 			By("creating a VPC that has an IPv6 CIDR")
@@ -155,10 +142,12 @@ var _ = Describe("(Integration) [EKS IPv6 test]", func() {
 				Spec: corev1.ServiceSpec{
 					IPFamilies: []corev1.IPFamily{corev1.IPv6Protocol},
 					Selector:   map[string]string{"app": "ipv6"},
-					Ports: []corev1.ServicePort{corev1.ServicePort{
-						Protocol: corev1.ProtocolTCP,
-						Port:     80,
-					}},
+					Ports: []corev1.ServicePort{
+						{
+							Protocol: corev1.ProtocolTCP,
+							Port:     80,
+						},
+					},
 				},
 			}, metav1.CreateOptions{})
 			Expect(err).ShouldNot(HaveOccurred())
@@ -199,3 +188,15 @@ var _ = Describe("(Integration) [EKS IPv6 test]", func() {
 		})
 	})
 })
+
+var _ = AfterSuite(func() {
+	cmd := params.EksctlDeleteCmd.WithArgs(
+		"cluster", params.ClusterName,
+		"--verbose", "2",
+	)
+	Expect(cmd).To(RunSuccessfully())
+
+	if params.KubeconfigTemp {
+		os.Remove(params.KubeconfigPath)
+	}
+})
