@@ -20,7 +20,7 @@ import (
 	"github.com/weaveworks/eksctl/pkg/eks"
 	"github.com/weaveworks/eksctl/pkg/testutils"
 
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 )
 
@@ -32,64 +32,48 @@ func init() {
 	params = tests.NewParams("kms")
 }
 
-func TestEKSkms(t *testing.T) {
+func TestEKSKMS(t *testing.T) {
 	testutils.RegisterAndRun(t)
 }
 
+var (
+	kmsKeyARN *string
+	ctl       api.ClusterProvider
+)
+
+var _ = BeforeSuite(func() {
+	clusterConfig := api.NewClusterConfig()
+	clusterConfig.Metadata.Name = params.ClusterName
+	clusterConfig.Metadata.Version = "latest"
+	clusterConfig.Metadata.Region = params.Region
+
+	data, err := json.Marshal(clusterConfig)
+	Expect(err).NotTo(HaveOccurred())
+
+	cmd := params.EksctlCreateCmd.
+		WithArgs(
+			"cluster",
+			"--config-file", "-",
+			"--verbose", "4",
+		).
+		WithoutArg("--region", params.Region).
+		WithStdin(bytes.NewReader(data))
+	Expect(cmd).To(RunSuccessfully())
+
+	clusterProvider, err := eks.New(context.TODO(), &api.ProviderConfig{Region: params.Region}, clusterConfig)
+	Expect(err).NotTo(HaveOccurred())
+	ctl = clusterProvider.Provider
+
+	kmsClient := kms.New(ctl.ConfigProvider())
+	output, err := kmsClient.CreateKey(&kms.CreateKeyInput{
+		Description: aws.String(fmt.Sprintf("Key to test KMS encryption on EKS cluster %s", params.ClusterName)),
+	})
+	Expect(err).NotTo(HaveOccurred())
+	kmsKeyARN = output.KeyMetadata.Arn
+})
+
 var _ = Describe("(Integration) [EKS kms test]", func() {
 	Context("Creating a cluster and enabling kms", func() {
-		var (
-			kmsKeyARN   *string
-			clusterName string
-			ctl         api.ClusterProvider
-		)
-
-		BeforeSuite(func() {
-			clusterName = params.NewClusterName("kms")
-			clusterConfig := api.NewClusterConfig()
-			clusterConfig.Metadata.Name = clusterName
-			clusterConfig.Metadata.Version = "latest"
-			clusterConfig.Metadata.Region = params.Region
-
-			data, err := json.Marshal(clusterConfig)
-			Expect(err).NotTo(HaveOccurred())
-
-			cmd := params.EksctlCreateCmd.
-				WithArgs(
-					"cluster",
-					"--config-file", "-",
-					"--verbose", "4",
-				).
-				WithoutArg("--region", params.Region).
-				WithStdin(bytes.NewReader(data))
-			Expect(cmd).To(RunSuccessfully())
-
-			clusterProvider, err := eks.New(context.TODO(), &api.ProviderConfig{Region: params.Region}, clusterConfig)
-			Expect(err).NotTo(HaveOccurred())
-			ctl = clusterProvider.Provider
-
-			kmsClient := kms.New(ctl.ConfigProvider())
-			output, err := kmsClient.CreateKey(&kms.CreateKeyInput{
-				Description: aws.String(fmt.Sprintf("Key to test KMS encryption on EKS cluster %s", clusterName)),
-			})
-			Expect(err).NotTo(HaveOccurred())
-			kmsKeyARN = output.KeyMetadata.Arn
-		})
-
-		AfterSuite(func() {
-			cmd := params.EksctlDeleteCmd.WithArgs(
-				"cluster", clusterName,
-				"--verbose", "2",
-			)
-			Expect(cmd).To(RunSuccessfully())
-
-			kmsClient := kms.New(ctl.ConfigProvider())
-			_, err := kmsClient.ScheduleKeyDeletion(&kms.ScheduleKeyDeletionInput{
-				KeyId:               kmsKeyARN,
-				PendingWindowInDays: aws.Int64(7),
-			})
-			Expect(err).NotTo(HaveOccurred())
-		})
 
 		It("supports enabling KMS encryption", func() {
 			enableEncryptionCMD := func() Cmd {
@@ -97,7 +81,7 @@ var _ = Describe("(Integration) [EKS kms test]", func() {
 					WithTimeout(2*time.Hour).
 					WithArgs(
 						"enable-secrets-encryption",
-						"--cluster", clusterName,
+						"--cluster", params.ClusterName,
 						"--key-arn", *kmsKeyARN,
 					)
 			}
@@ -118,3 +102,18 @@ var _ = Describe("(Integration) [EKS kms test]", func() {
 		})
 	})
 })
+
+var _ = AfterSuite(func() {
+	cmd := params.EksctlDeleteCmd.WithArgs(
+		"cluster", params.ClusterName,
+		"--verbose", "2",
+	)
+	Expect(cmd).To(RunSuccessfully())
+
+	kmsClient := kms.New(ctl.ConfigProvider())
+	_, err := kmsClient.ScheduleKeyDeletion(&kms.ScheduleKeyDeletionInput{
+		KeyId:               kmsKeyARN,
+		PendingWindowInDays: aws.Int64(7),
+	})
+	Expect(err).NotTo(HaveOccurred())
+})
