@@ -14,7 +14,7 @@ import (
 	awseks "github.com/aws/aws-sdk-go/service/eks"
 
 	"github.com/kris-nova/logger"
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 	"github.com/stretchr/testify/mock"
 	corev1 "k8s.io/api/core/v1"
