@@ -5,8 +5,9 @@ import (
 	"fmt"
 	"strings"
 
-	. "github.com/onsi/ginkgo/extensions/table"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
+
 	"github.com/pkg/errors"
 
 	"github.com/weaveworks/eksctl/pkg/actions/nodegroup"
