@@ -256,6 +256,9 @@ func (c *ClusterConfig) ValidateVPCConfig() error {
 		if c.VPC.NAT != nil {
 			return fmt.Errorf("setting NAT is not supported with IPv6")
 		}
+		if len(c.LocalZones) > 0 {
+			return errors.New("localZones are not supported with IPv6")
+		}
 	}
 
 	// manageSharedNodeSecurityGroupRules cannot be disabled if using eksctl managed security groups
@@ -263,6 +266,15 @@ func (c *ClusterConfig) ValidateVPCConfig() error {
 		return errors.New("vpc.manageSharedNodeSecurityGroupRules must be enabled when using ekstcl-managed security groups")
 	}
 
+	if len(c.LocalZones) > 0 {
+		if c.VPC.ID != "" {
+			return errors.New("localZones are not supported with a pre-existing VPC")
+		}
+		if c.VPC.NAT != nil && c.VPC.NAT.Gateway != nil && *c.VPC.NAT.Gateway == ClusterHighlyAvailableNAT {
+			return fmt.Errorf("%s NAT gateway is not supported for localZones", ClusterHighlyAvailableNAT)
+		}
+	}
+
 	return nil
 }
 
@@ -368,6 +380,9 @@ func (c *ClusterConfig) ValidatePrivateCluster() error {
 		if c.VPC != nil && c.VPC.ClusterEndpoints == nil {
 			c.VPC.ClusterEndpoints = &ClusterEndpoints{}
 		}
+		if len(c.LocalZones) > 0 {
+			return errors.New("localZones cannot be used in a fully-private cluster")
+		}
 		// public access is initially enabled to allow running operations that access the Kubernetes API
 		c.VPC.ClusterEndpoints.PublicAccess = Enabled()
 		c.VPC.ClusterEndpoints.PrivateAccess = Enabled()
@@ -630,8 +645,8 @@ func ValidateNodeGroup(i int, ng *NodeGroup) error {
 		}
 	}
 
-	if ng.AMI != "" && ng.OverrideBootstrapCommand == nil {
-		return errors.Errorf("%s.overrideBootstrapCommand is required when using a custom AMI (%s.ami)", path, path)
+	if ng.AMI != "" && ng.OverrideBootstrapCommand == nil && ng.AMIFamily != NodeImageFamilyBottlerocket {
+		return errors.Errorf("%[1]s.overrideBootstrapCommand is required when using a custom AMI (%[1]s.ami)", path)
 	}
 
 	if err := validateTaints(ng.Taints); err != nil {
@@ -718,6 +733,10 @@ func ValidateNodeGroup(i int, ng *NodeGroup) error {
 		}
 	}
 
+	if len(ng.LocalZones) > 0 && len(ng.AvailabilityZones) > 0 {
+		return errors.New("cannot specify both localZones and availabilityZones")
+	}
+
 	return nil
 }
 
