@@ -1,7 +1,7 @@
 package outputs_test
 
 import (
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
 	"github.com/aws/aws-sdk-go-v2/service/cloudformation/types"
