@@ -72,15 +72,12 @@ func doDisassociateIdentityProvider(cmd *cmdutils.Cmd, cliProvidedIDP cliProvide
 	}
 
 	cfg := cmd.ClusterConfig
-	meta := cmd.ClusterConfig.Metadata
 
 	ctl, err := cmd.NewProviderForExistingCluster()
 	if err != nil {
 		return err
 	}
 
-	cmdutils.LogRegionAndVersionInfo(meta)
-
 	if ok, err := ctl.CanOperate(cfg); !ok {
 		return err
 	}
