@@ -7,13 +7,14 @@ import (
 	"os"
 	"time"
 
-	"github.com/gofrs/flock"
-
 	"github.com/aws/aws-sdk-go-v2/credentials/stscreds"
 	"github.com/aws/aws-sdk-go-v2/service/autoscaling"
 	"github.com/aws/aws-sdk-go-v2/service/cloudtrail"
 	"github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs"
+	"github.com/aws/aws-sdk-go-v2/service/ec2"
+	ec2types "github.com/aws/aws-sdk-go-v2/service/ec2/types"
 	"github.com/aws/aws-sdk-go-v2/service/sts"
+
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/client"
 	"github.com/aws/aws-sdk-go/aws/credentials"
@@ -23,6 +24,8 @@ import (
 	"github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/aws-sdk-go/service/cloudformation/cloudformationiface"
 
+	"github.com/gofrs/flock"
+
 	awseks "github.com/aws/aws-sdk-go/service/eks"
 	"github.com/aws/aws-sdk-go/service/eks/eksiface"
 
@@ -347,6 +350,35 @@ func SetAvailabilityZones(ctx context.Context, spec *api.ClusterConfig, given []
 	return nil
 }
 
+// ValidateLocalZones validates that the specified local zones exist.
+func ValidateLocalZones(ctx context.Context, ec2API awsapi.EC2, localZones []string, region string) error {
+	output, err := ec2API.DescribeAvailabilityZones(ctx, &ec2.DescribeAvailabilityZonesInput{
+		ZoneNames: localZones,
+		Filters: []ec2types.Filter{
+			{
+				Name:   aws.String("region-name"),
+				Values: []string{region},
+			},
+			{
+				Name:   aws.String("state"),
+				Values: []string{string(ec2types.AvailabilityZoneStateAvailable)},
+			},
+		},
+	})
+	if err != nil {
+		return fmt.Errorf("error describing availability zones: %w", err)
+	}
+	if len(output.AvailabilityZones) != len(localZones) {
+		return fmt.Errorf("failed to find all local zones; expected to find %d available local zones but found only %d", len(localZones), len(output.AvailabilityZones))
+	}
+	for _, z := range output.AvailabilityZones {
+		if *z.ZoneType != "local-zone" {
+			return fmt.Errorf("non local-zone %q specified in localZones", *z.ZoneName)
+		}
+	}
+	return nil
+}
+
 func (c *ClusterProvider) newSession(spec *api.ProviderConfig) *session.Session {
 	// we might want to use bits from kops, although right now it seems like too many things we
 	// don't want yet
