@@ -73,6 +73,7 @@ func (w *WindowsIPAMTask) Describe() string {
 
 // VPCControllerTask represents a task to install the VPC controller
 type VPCControllerTask struct {
+	Context         context.Context
 	Info            string
 	ClusterProvider *ClusterProvider
 	ClusterConfig   *api.ClusterConfig
@@ -105,7 +106,7 @@ func (v *VPCControllerTask) Do(errCh chan error) error {
 
 	// TODO PlanMode doesn't work as intended
 	vpcController := addons.NewVPCController(rawClient, irsa, v.ClusterConfig.Status, v.ClusterProvider.Provider.Region(), v.PlanMode)
-	if err := vpcController.Deploy(); err != nil {
+	if err := vpcController.Deploy(v.Context); err != nil {
 		return errors.Wrap(err, "error installing VPC controller")
 	}
 	return nil
@@ -271,7 +272,7 @@ func (c *ClusterProvider) CreateExtraClusterConfigTasks(ctx context.Context, cfg
 	}
 
 	if api.IsEnabled(cfg.IAM.WithOIDC) {
-		c.appendCreateTasksForIAMServiceAccounts(cfg, newTasks)
+		c.appendCreateTasksForIAMServiceAccounts(ctx, cfg, newTasks)
 	}
 
 	if len(cfg.IdentityProviders) > 0 {
@@ -390,7 +391,7 @@ func (c *ClusterProvider) ClusterTasksForNodeGroups(cfg *api.ClusterConfig, inst
 	return tasks
 }
 
-func (c *ClusterProvider) appendCreateTasksForIAMServiceAccounts(cfg *api.ClusterConfig, tasks *tasks.TaskTree) {
+func (c *ClusterProvider) appendCreateTasksForIAMServiceAccounts(ctx context.Context, cfg *api.ClusterConfig, tasks *tasks.TaskTree) {
 	// we don't have all the information to construct full iamoidc.OpenIDConnectManager now,
 	// instead we just create a reference that gets updated when first task runs, and gets
 	// used by this would be more elegant if it was all done via CloudFormation and we didn't
@@ -405,7 +406,7 @@ func (c *ClusterProvider) appendCreateTasksForIAMServiceAccounts(cfg *api.Cluste
 			if err != nil {
 				return err
 			}
-			if err := oidc.CreateProvider(); err != nil {
+			if err := oidc.CreateProvider(ctx); err != nil {
 				return err
 			}
 			*oidcPlaceholder = *oidc
