@@ -9,7 +9,7 @@ import (
 
 	"github.com/aws/smithy-go"
 
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
 	"github.com/weaveworks/eksctl/pkg/eks/mocksv2"
